import { addClass, removeClass } from "@dft-vue-2-opentiny/vue-renderless/common/deps/dom";
import { defineComponent, $prefix } from "@dft-vue-2-opentiny/vue-common";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

import "@dft-vue-2-opentiny/vue-theme/collapse/index.css";
var __vue2_script = defineComponent({
  name: $prefix + "CollapseTransition",
  setup: function setup() {
    return {
      on: {
        beforeEnter: function beforeEnter(elem) {
          addClass(elem, "collapse-transition");
          if (!elem.dataset)
            elem.dataset = {};
          elem.dataset.oldPaddingBottom = elem.style.paddingBottom;
          elem.dataset.oldPaddingTop = elem.style.paddingTop;
          elem.style.height = "0";
          elem.style.paddingTop = 0;
          elem.style.paddingBottom = 0;
        },
        enter: function enter(elem) {
          elem.dataset.oldOverflow = elem.style.overflow;
          if (elem.scrollHeight === 0) {
            elem.style.height = "";
            elem.style.paddingBottom = elem.dataset.oldPaddingBottom;
            elem.style.paddingTop = elem.dataset.oldPaddingTop;
          } else {
            elem.style.height = elem.scrollHeight + "px";
            elem.style.paddingBottom = elem.dataset.oldPaddingBottom;
            elem.style.paddingTop = elem.dataset.oldPaddingTop;
          }
          elem.style.overflow = "hidden";
        },
        afterEnter: function afterEnter(elem) {
          removeClass(elem, "collapse-transition");
          elem.style.height = "";
          elem.style.overflow = elem.dataset.oldOverflow;
        },
        beforeLeave: function beforeLeave(elem) {
          if (!elem.dataset)
            elem.dataset = {};
          elem.dataset.oldOverflow = elem.style.overflow;
          elem.dataset.oldPaddingBottom = elem.style.paddingBottom;
          elem.dataset.oldPaddingTop = elem.style.paddingTop;
          elem.style.height = elem.scrollHeight + "px";
          elem.style.overflow = "hidden";
        },
        leave: function leave(elem) {
          if (elem.scrollHeight === 0)
            return;
          addClass(elem, "collapse-transition");
          elem.style.transitionProperty = "height";
          elem.style.height = 0;
          elem.style.paddingTop = 0;
          elem.style.paddingBottom = 0;
        },
        afterLeave: function afterLeave(elem) {
          removeClass(elem, "collapse-transition");
          elem.style.height = "";
          elem.style.overflow = elem.dataset.oldOverflow;
          elem.style.paddingBottom = elem.dataset.oldPaddingBottom;
          elem.style.paddingTop = elem.dataset.oldPaddingTop;
        }
      }
    };
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", _vm._g({}, _vm.on), [_vm._t("default")], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var CollapseTransition = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.8.0";
CollapseTransition.install = function(Vue) {
  Vue.component(CollapseTransition.name, CollapseTransition);
};
CollapseTransition.version = version;
export {
  CollapseTransition as default
};
